@@ -11,8 +11,8 @@ package Spreadsheet::Edit::IO;
 
 # Allow "use <thismodule. VERSION ..." in development sandbox to not bomb
 { no strict 'refs'; ${__PACKAGE__."::VER"."SION"} = 1999.999; }
-our $VERSION = '1000.004'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
-our $DATE = '2023-08-28'; # DATE from Dist::Zilla::Plugin::OurDate
+our $VERSION = '1000.005'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
+our $DATE = '2023-09-03'; # DATE from Dist::Zilla::Plugin::OurDate
 
 # This module is derived from the old never-released Text:CSV::Spreadsheet
 
@@ -56,8 +56,8 @@ use Text::CSV ();
 # DDI 5.025 is needed for Windows-aware qsh()
 use Data::Dumper::Interp 5.025 qw/vis visq dvis dvisq ivis ivisq avis qsh qshlist u/;
 
-use Spreadsheet::Edit::Log qw/log_call fmt_call log_methcall fmt_methcall
-                              btw oops/;
+use Spreadsheet::Edit::Log qw/log_call fmt_call log_methcall fmt_methcall oops/,
+                           ':btw=IO${lno}:';
 our %SpreadsheetEdit_Log_Options = (
   is_public_api => sub{
      $_[1][3] =~ /(?: ::|^ )(?: [a-z][^:]* | OpenAsCsv | ConvertSpreadsheet )$/x
